// material class
// -Kyoung Shin Park (2014 Spring)
//////////////////////////////////////////////////////////////////////
#include "material.h"

namespace moglclass
{

Material::Material(void)
{
    Ambient[0] = 0.2f; Ambient[1] = 0.2f; Ambient[2] = 0.2f; Ambient[3] = 1.0f;
    Diffuse[0] = 0.8f; Diffuse[1] = 0.8f; Diffuse[2] = 0.8f; Diffuse[3] = 1.0f;
    Specular[0] = 0.0f; Specular[1] = 0.0f; Specular[2] = 0.0f; Specular[3] = 1.0f;
    Emission[0] = 0.0f; Emission[1] = 0.0f; Emission[2] = 0.0f; Emission[3] = 1.0f;
    Shininess = 1.0f;
}

Material::Material(glm::vec4& ambientAndDiffuse_)
{
    Ambient = ambientAndDiffuse_;
    Diffuse = ambientAndDiffuse_;
    Specular[0] = 0.0f; Specular[1] = 0.0f; Specular[2] = 0.0f; Specular[3] = 1.0f;
    Emission[0] = 0.0f; Emission[1] = 0.0f; Emission[2] = 0.0f; Emission[3] = 1.0f;
    Shininess = 1.0f;
}

Material::Material(glm::vec4& ambientAndDiffuse_, glm::vec4& specular_, float shininess_)
{
    Ambient = ambientAndDiffuse_;
    Diffuse = ambientAndDiffuse_;
    Specular = specular_;
    Emission[0] = 0.0f; Emission[1] = 0.0f; Emission[2] = 0.0f; Emission[3] = 1.0f;
    Shininess = shininess_;
}

Material::Material(glm::vec4& ambient_, glm::vec4& diffuse_, glm::vec4& specular_, float shininess_)
{
    Ambient = ambient_;
    Diffuse = diffuse_;
    Specular = specular_;
    Emission[0] = 0.0f; Emission[1] = 0.0f; Emission[2] = 0.0f; Emission[3] = 1.0f;
    Shininess = shininess_;
}

void Material::setAmbientAndDiffuse(glm::vec4& ambientAndDiffuse_)
{
    setAmbient(ambientAndDiffuse_);
    setDiffuse(ambientAndDiffuse_);
}

void Material::setAmbient(glm::vec4& ambient_)
{
    Ambient = ambient_;
}

void Material::setDiffuse(glm::vec4& diffuse_)
{
    Diffuse = diffuse_;
}

void Material::setSpecular(glm::vec4& specular_)
{
    Specular = specular_;
}

void Material::setEmission(glm::vec4& emission_)
{
    Emission = emission_;
}

void Material::setShininess(float shininess_)
{
    Shininess = shininess_;
}


// set material uniform variable
void Material::setUniform(Program* p, std::string materialName)
{
	p->setUniform(materialName+".Ambient", Ambient);
	p->setUniform(materialName+".Diffuse", Diffuse);
	p->setUniform(materialName+".Specular", Specular);
	p->setUniform(materialName+".Shininess", Shininess);
}

} // namespace
